<?php

/**
 * @file
 * Provides views hook routines.
 */

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\field\FieldStorageConfigInterface;

/**
 * Implements hook_field_views_data_alter().
 */
function county_field_views_data_alter(array &$data, FieldStorageConfigInterface $field_storage) {
  if ($field_storage->getType() != 'county') {
    return;
  }

  // Check whether the entity type storage is supported.
  $storage = _views_field_get_entity_type_storage($field_storage);
  if (!$storage) {
    return;
  }

  $field_name = $field_storage->getName();

  // Grab information about the entity type tables.
  // We need to join to both the base table and the data table, if available.
  $entity_type_manager = \Drupal::entityTypeManager();
  $entity_type_id = $field_storage->getTargetEntityTypeId();

  // Description of the field tables.
  // @todo Generalize this code to make it work with any table layout. See
  //   https://www.drupal.org/node/2079019.
  $table_mapping = $storage->getTableMapping();
  $field_tables = [
    EntityStorageInterface::FIELD_LOAD_CURRENT => [
      'table' => $table_mapping->getDedicatedDataTableName($field_storage),
      'alias' => "{$entity_type_id}__{$field_name}",
    ],
  ];
  if ($table_mapping->getDedicatedRevisionTableName($field_storage)) {
    $field_tables[EntityStorageInterface::FIELD_LOAD_REVISION] = [
      'table' => $table_mapping->getDedicatedRevisionTableName($field_storage),
      'alias' => "{$entity_type_id}_revision__{$field_name}",
    ];
  }

  $column_name = 'value';
  foreach ($field_tables as $type => $table_info) {
    $table = $table_info['table'];
    $table_alias = $table_info['alias'];

    $key = $column_real_name = $table_mapping->getFieldColumnName($field_storage, $column_name);
    if (isset($data[$table_alias][$key])) {
      // Set custom filter handler using text element.
      $data[$table_alias][$key]['filter']['id'] = 'county_basic';
      // Set custom filter handler using select element.
      $select_filter = $data[$table_alias][$key];
      unset($select_filter['argument'], $select_filter['sort']);
      $select_filter['title'] .= ' (select element)';
      $select_filter['help'] .= ' The exposed filter uses a select element.';
      $select_filter['filter']['id'] = 'county_many_to_one';
      $column_name = 'select';
      $key = $column_real_name = $table_mapping->getFieldColumnName($field_storage, $column_name);
      $data[$table_alias][$key] = $select_filter;
    }
  }
}
