<?php

namespace Drupal\county\Plugin;

use Drupal\Core\Database\Database;
use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\filter\StringFilter;

trait AdminAreaTrait {

  /**
   * Returns a county options list suitable for a select element.
   *
   * @param string $admin_area
   *   The administrative area.
   * @param array $settings
   *   The plugin settings (currently a field widget or views filter).
   *
   * @return array
   *   The county list corresponding to the administrative area.
   */
  public static function getCountyOptions($admin_area, array $settings) {
    $options = $none = [];
    if ($admin_area == '_none') {
      // @todo Check the '#empty_value' property of administrative area field.
      return $none;
    }

    extract($settings);
    $select_all ? $options['all'] = 'All counties' : '';

    $args = [':state' => $admin_area];
    $options += Database::getConnection()->query('SELECT CONCAT(fips_state, fips_county) AS fips, county FROM {county_fips} WHERE state = :state', $args)->fetchAllKeyed();
    if (empty(array_diff_key($options, array_flip(['_none', 'all'])))) {
      return $none;
    }

    if ($display_type == 'short') {
      // @todo Consider retrieving the fips_code and using it as basis to remove
      // 'county' from string. Or making this a widget setting.
      // @todo Sort the suffix strings: county is most likely. Use a replace
      // callback and return if a suffix is found.
      $suffixes = ['County', 'counties', 'Parish', 'City and Borough', 'Borough', 'Census Area', 'city', 'District', 'Municipality', 'Municipio', 'Island'];
      foreach ($options as $key => &$value) {
        $value = trim(str_replace($suffixes, '', $value));
      }
    }
    elseif ($display_type == 'key') {
      foreach ($options as $key => &$value) {
        $value = $key;
      }
    }
    if (isset($append_fips) && $append_fips) {
      foreach ($options as $key => &$value) {
        if ($key != '_none' && $key != 'all') {
          $value .= " ($key)";
        }
      }
    }

    return $options;
  }

}
