<?php

namespace Drupal\county\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'county_long' formatter.
 *
 * @FieldFormatter(
 *   id = "county_long",
 *   label = @Translation("Long"),
 *   description = @Translation("Display the county name."),
 *   field_types = {
 *     "county"
 *   }
 * )
 */
class Long extends Base {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'append_fips' => FALSE,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    // Build form elements.
    $form['append_fips'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Append FIPS code'),
      '#description' => $this->t('If checked, then append FIPS code to display value.'),
      '#default_value' => $this->getSetting('append_fips'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();

    $summary = parent::settingsSummary();
    $summary[] = $settings['append_fips'] ? $this->t('Append FIPS code to display value.') : NULL;
    $summary = array_values(array_filter($summary));
    $summary += [$this->t('Display each value.')];

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  protected function viewValues(array $items, $admin_area, array $settings) {
    $elements = [];
    foreach ($items as $delta => $item) {
      $extra = $settings['append_fips'] && !in_array($delta, ['_none', 'all'], TRUE) ? " ({$item['value']})" : '';
      $output = Xss::filter($this->countyDisplayValue($admin_area, $item['value']) . $extra);
      $elements[$delta] = ['#markup' => $output];
    }
    return $elements;
  }

}
