<?php

namespace Drupal\county\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Xss;

/**
 * Plugin implementation of the 'county_short' formatter.
 *
 * @FieldFormatter(
 *   id = "county_short",
 *   label = @Translation("Short"),
 *   description = @Translation("Display the county name without suffix."),
 *   field_types = {
 *     "county"
 *   }
 * )
 */
class Short extends Long {

  /**
   * {@inheritdoc}
   */
  protected function viewValues(array $items, $admin_area, array $settings) {
    $elements = [];
    // @todo Sort the suffix strings: county is most likely. Use a replace
    // callback and return if a suffix is found.
    $suffixes = ['County', 'counties', 'Parish', 'City and Borough', 'Borough', 'Census Area', 'city', 'District', 'Municipality', 'Municipio', 'Island'];
    foreach ($items as $delta => $item) {
      $extra = $settings['append_fips'] && !in_array($delta, ['_none', 'all'], TRUE) ? " ({$item['value']})" : '';
      $output = trim(str_replace($suffixes, '', $this->countyDisplayValue($admin_area, $item['value'])));
      $output = Xss::filter($output . $extra);
      $elements[$delta] = ['#markup' => $output];
    }
    return $elements;
  }

}
