<?php

namespace Drupal\county\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'county' field type.
 *
 * @FieldType(
 *   id = "county",
 *   label = @Translation("County"),
 *   description = @Translation("A field containing a US county FIPS code."),
 *   default_widget = "county_select",
 *   default_formatter = "county_long"
 * )
 */
class County extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'admin_area_field' => '',
    ] + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
      ->setLabel(t('County value'))
      ->setRequired(TRUE);

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return [
      'columns' => [
        'value' => [
          'type' => 'varchar',
          'length' => 5,
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return empty($value) || (string) $value === '_none';
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();

    $entity_type_id = $this->getFieldDefinition()->getTargetEntityTypeId();
    $bundle = $this->getFieldDefinition()->getTargetBundle();

    $supported_field_types = ['string', 'list_string'];
    $potential_fields = [];

    // Get the fields on the bundle.
    // @todo This belongs in core. This was copied from field_entity_bundle_delete().
    $storage = \Drupal::entityTypeManager()->getStorage('field_config');
    $fields = $storage->loadByProperties(['entity_type' => $entity_type_id, 'bundle' => $bundle]);
    foreach ($fields as $name => $field) {
      if (in_array($field->getType(), $supported_field_types)) {
        $potential_fields[$field->getName()] = $field->getLabel();
      }
    }

    // @todo Require cardinality = 1 on the admin_area_field?
    // @todo Add a hidden country field so this is ready to handle all tuples of
    // (country, admin_area, sub admin_area).
    $element['admin_area_field'] = [
      '#type' => 'select',
      '#title' => $this->t('State field'),
      '#default_value' => isset($settings['admin_area_field']) ? $settings['admin_area_field']: '',
      '#options' => $potential_fields,
      '#description' => $this->t('Select the state field used to filter the county list.'),
      '#required' => TRUE,
    ];

    return $element;
  }

}
